/*
 * Copyright (c) 2020 Texas Instruments Incorporated - http://www.ti.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

#ifndef BOARD_H
#define BOARD_H

//*****************************************************************************
//
// If building with a C++ compiler, make all of the definitions in this header
// have a C binding.
//
//*****************************************************************************
#ifdef __cplusplus
extern "C"
{
#endif

//
// Included Files
//

#include "driverlib.h"
#include "device.h"

//*****************************************************************************
//
// PinMux Configurations
//
//*****************************************************************************
//
// GPIO10 - GPIO Settings
//
#define myGPIO10AdcTrig_GPIO_PIN_CONFIG GPIO_10_GPIO10
//
// GPIO11 - GPIO Settings
//
#define myGPIO11SpiCs_GPIO_PIN_CONFIG GPIO_11_GPIO11
//
// GPIO0 - GPIO Settings
//
#define CH_FAULT1_GPIO_PIN_CONFIG GPIO_0_GPIO0
//
// GPIO1 - GPIO Settings
//
#define CH_FAULT2_GPIO_PIN_CONFIG GPIO_1_GPIO1
//
// GPIO2 - GPIO Settings
//
#define CH_FAULT3_GPIO_PIN_CONFIG GPIO_2_GPIO2
//
// GPIO3 - GPIO Settings
//
#define CH_FAULT4_GPIO_PIN_CONFIG GPIO_3_GPIO3
//
// GPIO4 - GPIO Settings
//
#define CH_FAULT5_GPIO_PIN_CONFIG GPIO_4_GPIO4
//
// GPIO5 - GPIO Settings
//
#define CH_FAULT6_GPIO_PIN_CONFIG GPIO_5_GPIO5
//
// GPIO6 - GPIO Settings
//
#define CH_FAULT7_GPIO_PIN_CONFIG GPIO_6_GPIO6
//
// GPIO7 - GPIO Settings
//
#define CH_FAULT8_GPIO_PIN_CONFIG GPIO_7_GPIO7
//
// GPIO33 - GPIO Settings
//
#define RELAY_EN_GPIO_PIN_CONFIG GPIO_33_GPIO33
//
// GPIO35 - GPIO Settings
//
#define U_RESET_GPIO_PIN_CONFIG GPIO_35_GPIO35

//
// SPIA -> mySPI0 Pinmux
//
//
// SPIA_PICO - GPIO Settings
//
#define GPIO_PIN_SPIA_PICO 16
#define mySPI0_SPIPICO_GPIO 16
#define mySPI0_SPIPICO_PIN_CONFIG GPIO_16_SPIA_SIMO
//
// SPIA_POCI - GPIO Settings
//
#define GPIO_PIN_SPIA_POCI 17
#define mySPI0_SPIPOCI_GPIO 17
#define mySPI0_SPIPOCI_PIN_CONFIG GPIO_17_SPIA_SOMI
//
// SPIA_CLK - GPIO Settings
//
#define GPIO_PIN_SPIA_CLK 18
#define mySPI0_SPICLK_GPIO 18
#define mySPI0_SPICLK_PIN_CONFIG GPIO_18_SPIA_CLK
//
// SPIA_PTE - GPIO Settings
//
#define GPIO_PIN_SPIA_PTE 19
#define mySPI0_SPIPTE_GPIO 19
#define mySPI0_SPIPTE_PIN_CONFIG GPIO_19_SPIA_STEN

//*****************************************************************************
//
// ADC Configurations
//
//*****************************************************************************
#define myADCA_BASE ADCA_BASE
#define myADCA_RESULT_BASE ADCARESULT_BASE
#define myADCA_AMPOUT1 ADC_SOC_NUMBER0
#define myADCA_FORCE_AMPOUT1 ADC_FORCE_SOC0
#define myADCA_SAMPLE_WINDOW_AMPOUT1 75
#define myADCA_TRIGGER_SOURCE_AMPOUT1 ADC_TRIGGER_GPIO
#define myADCA_CHANNEL_AMPOUT1 ADC_CH_ADCIN0
#define myADCA_AMPOUT2 ADC_SOC_NUMBER1
#define myADCA_FORCE_AMPOUT2 ADC_FORCE_SOC1
#define myADCA_SAMPLE_WINDOW_AMPOUT2 75
#define myADCA_TRIGGER_SOURCE_AMPOUT2 ADC_TRIGGER_GPIO
#define myADCA_CHANNEL_AMPOUT2 ADC_CH_ADCIN1
#define myADCA_AMPOUT3 ADC_SOC_NUMBER2
#define myADCA_FORCE_AMPOUT3 ADC_FORCE_SOC2
#define myADCA_SAMPLE_WINDOW_AMPOUT3 75
#define myADCA_TRIGGER_SOURCE_AMPOUT3 ADC_TRIGGER_GPIO
#define myADCA_CHANNEL_AMPOUT3 ADC_CH_ADCIN2
#define myADCA_AMPOUT4 ADC_SOC_NUMBER3
#define myADCA_FORCE_AMPOUT4 ADC_FORCE_SOC3
#define myADCA_SAMPLE_WINDOW_AMPOUT4 75
#define myADCA_TRIGGER_SOURCE_AMPOUT4 ADC_TRIGGER_GPIO
#define myADCA_CHANNEL_AMPOUT4 ADC_CH_ADCIN3
#define myADCA_AMPOUT5 ADC_SOC_NUMBER4
#define myADCA_FORCE_AMPOUT5 ADC_FORCE_SOC4
#define myADCA_SAMPLE_WINDOW_AMPOUT5 75
#define myADCA_TRIGGER_SOURCE_AMPOUT5 ADC_TRIGGER_GPIO
#define myADCA_CHANNEL_AMPOUT5 ADC_CH_ADCIN4
#define myADCA_AMPOUT6 ADC_SOC_NUMBER5
#define myADCA_FORCE_AMPOUT6 ADC_FORCE_SOC5
#define myADCA_SAMPLE_WINDOW_AMPOUT6 75
#define myADCA_TRIGGER_SOURCE_AMPOUT6 ADC_TRIGGER_GPIO
#define myADCA_CHANNEL_AMPOUT6 ADC_CH_ADCIN5
void myADCA_init();

#define myADCB_BASE ADCB_BASE
#define myADCB_RESULT_BASE ADCBRESULT_BASE
#define myADCB_AMPOUT7 ADC_SOC_NUMBER0
#define myADCB_FORCE_AMPOUT7 ADC_FORCE_SOC0
#define myADCB_SAMPLE_WINDOW_AMPOUT7 75
#define myADCB_TRIGGER_SOURCE_AMPOUT7 ADC_TRIGGER_GPIO
#define myADCB_CHANNEL_AMPOUT7 ADC_CH_ADCIN0
#define myADCB_AMPOUT8 ADC_SOC_NUMBER1
#define myADCB_FORCE_AMPOUT8 ADC_FORCE_SOC1
#define myADCB_SAMPLE_WINDOW_AMPOUT8 75
#define myADCB_TRIGGER_SOURCE_AMPOUT8 ADC_TRIGGER_GPIO
#define myADCB_CHANNEL_AMPOUT8 ADC_CH_ADCIN1
#define myADCB_REFVOUT1 ADC_SOC_NUMBER2
#define myADCB_FORCE_REFVOUT1 ADC_FORCE_SOC2
#define myADCB_SAMPLE_WINDOW_REFVOUT1 75
#define myADCB_TRIGGER_SOURCE_REFVOUT1 ADC_TRIGGER_GPIO
#define myADCB_CHANNEL_REFVOUT1 ADC_CH_ADCIN2
#define myADCB_REFVOUT2 ADC_SOC_NUMBER3
#define myADCB_FORCE_REFVOUT2 ADC_FORCE_SOC3
#define myADCB_SAMPLE_WINDOW_REFVOUT2 75
#define myADCB_TRIGGER_SOURCE_REFVOUT2 ADC_TRIGGER_GPIO
#define myADCB_CHANNEL_REFVOUT2 ADC_CH_ADCIN3
void myADCB_init();

#define myADCC_BASE ADCC_BASE
#define myADCC_RESULT_BASE ADCCRESULT_BASE
#define myADCC_REFVOUT3 ADC_SOC_NUMBER2
#define myADCC_FORCE_REFVOUT3 ADC_FORCE_SOC2
#define myADCC_SAMPLE_WINDOW_REFVOUT3 75
#define myADCC_TRIGGER_SOURCE_REFVOUT3 ADC_TRIGGER_GPIO
#define myADCC_CHANNEL_REFVOUT3 ADC_CH_ADCIN2
#define myADCC_REFVOUT4 ADC_SOC_NUMBER3
#define myADCC_FORCE_REFVOUT4 ADC_FORCE_SOC3
#define myADCC_SAMPLE_WINDOW_REFVOUT4 75
#define myADCC_TRIGGER_SOURCE_REFVOUT4 ADC_TRIGGER_GPIO
#define myADCC_CHANNEL_REFVOUT4 ADC_CH_ADCIN3
#define myADCC_REFVOUT5 ADC_SOC_NUMBER4
#define myADCC_FORCE_REFVOUT5 ADC_FORCE_SOC4
#define myADCC_SAMPLE_WINDOW_REFVOUT5 75
#define myADCC_TRIGGER_SOURCE_REFVOUT5 ADC_TRIGGER_GPIO
#define myADCC_CHANNEL_REFVOUT5 ADC_CH_ADCIN4
void myADCC_init();

#define myADCD_BASE ADCD_BASE
#define myADCD_RESULT_BASE ADCDRESULT_BASE
#define myADCD_REFVOUT6 ADC_SOC_NUMBER0
#define myADCD_FORCE_REFVOUT6 ADC_FORCE_SOC0
#define myADCD_SAMPLE_WINDOW_REFVOUT6 75
#define myADCD_TRIGGER_SOURCE_REFVOUT6 ADC_TRIGGER_GPIO
#define myADCD_CHANNEL_REFVOUT6 ADC_CH_ADCIN0
#define myADCD_REFVOUT7 ADC_SOC_NUMBER1
#define myADCD_FORCE_REFVOUT7 ADC_FORCE_SOC1
#define myADCD_SAMPLE_WINDOW_REFVOUT7 75
#define myADCD_TRIGGER_SOURCE_REFVOUT7 ADC_TRIGGER_GPIO
#define myADCD_CHANNEL_REFVOUT7 ADC_CH_ADCIN1
#define myADCD_REFVOUT8 ADC_SOC_NUMBER2
#define myADCD_FORCE_REFVOUT8 ADC_FORCE_SOC2
#define myADCD_SAMPLE_WINDOW_REFVOUT8 75
#define myADCD_TRIGGER_SOURCE_REFVOUT8 ADC_TRIGGER_GPIO
#define myADCD_CHANNEL_REFVOUT8 ADC_CH_ADCIN2
void myADCD_init();


//*****************************************************************************
//
// GPIO Configurations
//
//*****************************************************************************
#define myGPIO10AdcTrig 10
void myGPIO10AdcTrig_init();
#define myGPIO11SpiCs 11
void myGPIO11SpiCs_init();
#define CH_FAULT1 0
void CH_FAULT1_init();
#define CH_FAULT2 1
void CH_FAULT2_init();
#define CH_FAULT3 2
void CH_FAULT3_init();
#define CH_FAULT4 3
void CH_FAULT4_init();
#define CH_FAULT5 4
void CH_FAULT5_init();
#define CH_FAULT6 5
void CH_FAULT6_init();
#define CH_FAULT7 6
void CH_FAULT7_init();
#define CH_FAULT8 7
void CH_FAULT8_init();
#define RELAY_EN 33
void RELAY_EN_init();
#define U_RESET 35
void U_RESET_init();

//*****************************************************************************
//
// INPUTXBAR Configurations
//
//*****************************************************************************
#define myINPUTXBARINPUT10_SOURCE 10
#define myINPUTXBARINPUT10_INPUT XBAR_INPUT5
void myINPUTXBARINPUT10_init();

//*****************************************************************************
//
// SPI Configurations
//
//*****************************************************************************
#define mySPI0_BASE SPIA_BASE
#define mySPI0_BITRATE 1000000
void mySPI0_init();

//*****************************************************************************
//
// Board Configurations
//
//*****************************************************************************
void	Board_init();
void	ADC_init();
void	GPIO_init();
void	INPUTXBAR_init();
void	SPI_init();
void	PinMux_init();

//*****************************************************************************
//
// Mark the end of the C bindings section for C++ compilers.
//
//*****************************************************************************
#ifdef __cplusplus
}
#endif

#endif  // end of BOARD_H definition
